@@ -13,7 +13,7 @@ def execute_python(codes:str) -> str:
         else:
             codes = parts[1].rstrip('`')
     codes = codes.strip().strip('`')
-    print(f"execute_python([{codes}])")
+    #print("execute_python:{\n%s\n}" % codes)
 
     cp = subprocess.Popen(["python3", "-c", codes], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
     out = cp.communicate()[0].decode().strip()
